@@ -35,7 +35,12 @@ DirectivityShaperAudioProcessor::DirectivityShaperAudioProcessor() :
         #if ! JucePlugin_IsSynth
             .withInput ("Input", juce::AudioChannelSet::mono(), true)
         #endif
-            .withOutput ("Output", juce::AudioChannelSet::discreteChannels (64), true)
+            .withOutput ("Output",
+                         ((juce::PluginHostType::getPluginLoadedAs()
+                           == juce::AudioProcessor::wrapperType_VST3)
+                              ? juce::AudioChannelSet::ambisonic (1)
+                              : juce::AudioChannelSet::ambisonic (7)),
+                         true)
     #endif
             ,
 #endif
