@@ -30,9 +30,19 @@ MultiBandCompressorAudioProcessor::MultiBandCompressorAudioProcessor() :
         BusesProperties()
     #if ! JucePlugin_IsMidiEffect
         #if ! JucePlugin_IsSynth
-            .withInput ("Input", juce::AudioChannelSet::discreteChannels (64), true)
+            .withInput ("Input",
+                        ((juce::PluginHostType::getPluginLoadedAs()
+                          == juce::AudioProcessor::wrapperType_VST3)
+                             ? juce::AudioChannelSet::ambisonic (1)
+                             : juce::AudioChannelSet::ambisonic (7)),
+                        true)
         #endif
-            .withOutput ("Output", juce::AudioChannelSet::discreteChannels (64), true)
+            .withOutput ("Output",
+                         ((juce::PluginHostType::getPluginLoadedAs()
+                           == juce::AudioProcessor::wrapperType_VST3)
+                              ? juce::AudioChannelSet::ambisonic (1)
+                              : juce::AudioChannelSet::ambisonic (7)),
+                         true)
     #endif
             ,
 #endif
@@ -301,6 +311,11 @@ std::vector<std::unique_ptr<juce::RangedAudioParameter>>
         params.push_back (std::move (boolParam));
     }
 
+    auto boolParam = std::make_unique<juce::AudioParameterBool> ("displayOverallMagnitude",
+                                                                 "Display overall magnitude",
+                                                                 false);
+    params.push_back (std::move (boolParam));
+
     return params;
 }
 
