@@ -32,7 +32,7 @@ PluginTemplateAudioProcessor::PluginTemplateAudioProcessor() :
         #if ! JucePlugin_IsSynth
             .withInput ("Input", juce::AudioChannelSet::discreteChannels (10), true)
         #endif
-            .withOutput ("Output", juce::AudioChannelSet::discreteChannels (64), true)
+            .withOutput ("Output", juce::AudioChannelSet::ambisonic (7), true)
     #endif
             ,
 #endif
