@@ -1,4 +1,4 @@
- /*
+/*
  ==============================================================================
  This file is part of the IEM plug-in suite.
  Authors: Daniel Rudrich
@@ -20,7 +20,6 @@
  ==============================================================================
  */
 
-
 #pragma once
 #include "../JuceLibraryCode/JuceHeader.h"
 
@@ -28,10 +27,7 @@ using namespace juce::dsp;
 class Delay : private ProcessorBase
 {
 public:
-
-    Delay()
-    {
-    }
+    Delay() {}
     ~Delay() override = default;
 
     void setDelayTime (float delayTimeInSeconds)
@@ -47,13 +43,10 @@ public:
             bypassed = false;
         }
 
-        prepare(spec);
+        prepare (spec);
     }
 
-    const int getDelayInSamples()
-    {
-        return bypassed ? 0 : delayInSamples;
-    }
+    const int getDelayInSamples() { return bypassed ? 0 : delayInSamples; }
 
     void prepare (const juce::dsp::ProcessSpec& specs) override
     {
@@ -61,7 +54,7 @@ public:
 
         delayInSamples = delay * specs.sampleRate;
 
-        buffer.setSize(specs.numChannels, specs.maximumBlockSize + delayInSamples);
+        buffer.setSize (specs.numChannels, specs.maximumBlockSize + delayInSamples);
         buffer.clear();
         writePosition = 0;
     }
@@ -75,44 +68,46 @@ public:
             auto abIn = context.getInputBlock();
             auto abOut = context.getOutputBlock();
             auto L = abIn.getNumSamples();
-            auto nCh = juce::jmin((int) spec.numChannels, (int) abIn.getNumChannels());
+            auto nCh = juce::jmin ((int) spec.numChannels, (int) abIn.getNumChannels());
 
             int startIndex, blockSize1, blockSize2;
 
-
             // write in delay line
-            getReadWritePositions(false, (int) L, startIndex, blockSize1, blockSize2);
+            getReadWritePositions (false, (int) L, startIndex, blockSize1, blockSize2);
 
             for (int ch = 0; ch < nCh; ch++)
-                buffer.copyFrom(ch, startIndex, abIn.getChannelPointer(ch), blockSize1);
+                buffer.copyFrom (ch, startIndex, abIn.getChannelPointer (ch), blockSize1);
 
             if (blockSize2 > 0)
                 for (int ch = 0; ch < nCh; ch++)
-                    buffer.copyFrom(ch, 0, abIn.getChannelPointer(ch) + blockSize1, blockSize2);
-
+                    buffer.copyFrom (ch, 0, abIn.getChannelPointer (ch) + blockSize1, blockSize2);
 
             // read from delay line
-            getReadWritePositions(true, (int) L, startIndex, blockSize1, blockSize2);
+            getReadWritePositions (true, (int) L, startIndex, blockSize1, blockSize2);
 
             for (int ch = 0; ch < nCh; ch++)
-                juce::FloatVectorOperations::copy(abOut.getChannelPointer(ch), buffer.getReadPointer(ch) + startIndex, blockSize1);
+                juce::FloatVectorOperations::copy (abOut.getChannelPointer (ch),
+                                                   buffer.getReadPointer (ch) + startIndex,
+                                                   blockSize1);
 
             if (blockSize2 > 0)
                 for (int ch = 0; ch < nCh; ch++)
-                    juce::FloatVectorOperations::copy(abOut.getChannelPointer(ch) + blockSize1, buffer.getReadPointer(ch), blockSize2);
-
+                    juce::FloatVectorOperations::copy (abOut.getChannelPointer (ch) + blockSize1,
+                                                       buffer.getReadPointer (ch),
+                                                       blockSize2);
 
             writePosition += L;
             writePosition = writePosition % buffer.getNumSamples();
         }
     }
 
-    void reset() override
-    {
+    void reset() override {}
 
-    }
-
-    void getReadWritePositions (bool read, int numSamples, int& startIndex, int& blockSize1, int& blockSize2)
+    void getReadWritePositions (bool read,
+                                int numSamples,
+                                int& startIndex,
+                                int& blockSize1,
+                                int& blockSize2)
     {
         const int L = buffer.getNumSamples();
         int pos = writePosition;
@@ -124,7 +119,7 @@ public:
             pos = pos + L;
         pos = pos % L;
 
-        jassert(pos >= 0 && pos < L);
+        jassert (pos >= 0 && pos < L);
 
         if (numSamples <= 0)
         {
@@ -143,7 +138,7 @@ public:
 
 private:
     //==============================================================================
-    juce::dsp::ProcessSpec spec = {-1, 0, 0};
+    juce::dsp::ProcessSpec spec = { -1, 0, 0 };
     float delay;
     int delayInSamples = 0;
     bool bypassed = false;
