@@ -22,6 +22,7 @@
 
 #pragma once
 #include "../JuceLibraryCode/JuceHeader.h"
+#include "FilterVisualizerHelper.h"
 #include "WalshHadamard/fwht.h"
 using namespace juce::dsp;
 class FeedbackDelayNetwork : private ProcessorBase
@@ -38,14 +39,23 @@ public:
         nano = 8,
         tiny = 16,
         small = 32,
-        big = 64
+        big = 64,
+        huge = 128,
+        giant = 256
     };
 
     struct FilterParameter
     {
         float frequency = 1000.0f;
         float linearGain = 1.0f;
-        float q = 0.707f;
+        float q = 0.7071f;
+    };
+
+    struct HPFilterParameter
+    {
+        int mode = 0;
+        float frequency = 20.0f;
+        float q = 0.7071f;
     };
 
     FeedbackDelayNetwork (FdnSize size = big)
@@ -73,15 +83,20 @@ public:
     void prepare (const juce::dsp::ProcessSpec& newSpec) override
     {
         spec = newSpec;
+        isInitialized = true;
 
         indices = indexGen (fdnSize, delayLength);
         updateParameterSettings();
+        updateGuiCoefficients();
 
         for (int ch = 0; ch < fdnSize; ++ch)
         {
             delayBufferVector[ch]->clear();
             lowShelfFilters[ch]->reset();
             highShelfFilters[ch]->reset();
+
+            hpFilters[ch]->reset (0.0f);
+            additionalHpFilters[ch]->reset (0.0f);
         }
     }
 
@@ -100,16 +115,16 @@ public:
         {
             lowShelfParameters = params.newLowShelfParams;
             highShelfParameters = params.newHighShelfParams;
+            hpFilterParameters = params.newHPFilterParams;
             params.needParameterUpdate = true;
             params.filterParametersChanged = false;
         }
 
         if (params.networkSizeChanged)
         {
-            fdnSize = params.newNetworkSize;
             params.needParameterUpdate = true;
             params.networkSizeChanged = false;
-            updateFdnSize (fdnSize);
+            updateFdnSize (params.newNetworkSize);
         }
 
         if (params.delayLengthChanged)
@@ -160,11 +175,7 @@ public:
         //            }
         //        }
 
-        float dryGain;
-        if (freeze)
-            dryGain = dryWet;
-        else
-            dryGain = 1.0f - dryWet;
+        float dryGain = 1.0f - dryWet;
 
         for (int i = 0; i < numSamples; ++i)
         {
@@ -188,6 +199,14 @@ public:
 
                 if (! freeze)
                 {
+                    // Apply highpass filter
+                    if (hpFilterParameters.mode != 0)
+                        delayData[delayPos] =
+                            hpFilters[channel]->processSample (delayData[delayPos]);
+
+                    if (hpFilterParameters.mode == 3)
+                        delayData[delayPos] =
+                            additionalHpFilters[channel]->processSample (delayData[delayPos]);
                     // apply shelving filters
                     delayData[delayPos] =
                         highShelfFilters[channel]->processSingleSampleRaw (delayData[delayPos]);
@@ -256,10 +275,13 @@ public:
     }
 
     void reset() override {}
-    void setFilterParameter (FilterParameter lowShelf, FilterParameter highShelf)
+    void setFilterParameter (FilterParameter lowShelf,
+                             FilterParameter highShelf,
+                             HPFilterParameter hp)
     {
         params.newLowShelfParams = lowShelf;
         params.newHighShelfParams = highShelf;
+        params.newHPFilterParams = hp;
         params.filterParametersChanged = true;
     }
 
@@ -278,31 +300,87 @@ public:
         params.overallGainChanged = true;
     }
 
-    void getT60ForFrequencyArray (double* frequencies, double* t60Data, size_t numSamples)
+    juce::dsp::IIR::Coefficients<double>::Ptr getCoefficientsForGui (const int filterIndex) const
     {
-        juce::dsp::IIR::Coefficients<float> coefficients;
-        coefficients = *IIR::Coefficients<float>::makeLowShelf (
+        return guiCoefficients[filterIndex];
+    }
+
+    void updateGuiCoefficients()
+    {
+        // Highpass coefficients
+        switch (hpFilterParameters.mode)
+        {
+            case 0:
+                guiCoefficients[0] =
+                    IIR::Coefficients<double>::makeAllPass (spec.sampleRate, 20.0f);
+                break;
+            case 1:
+                guiCoefficients[0] = IIR::Coefficients<double>::makeFirstOrderHighPass (
+                    spec.sampleRate,
+                    juce::jmin (0.5 * spec.sampleRate,
+                                static_cast<double> (hpFilterParameters.frequency)));
+                break;
+            case 2:
+                guiCoefficients[0] = IIR::Coefficients<double>::makeHighPass (
+                    spec.sampleRate,
+                    juce::jmin (0.5 * spec.sampleRate,
+                                static_cast<double> (hpFilterParameters.frequency)),
+                    hpFilterParameters.q);
+                break;
+            case 3:
+            {
+                auto coeffs = IIR::Coefficients<double>::makeHighPass (
+                    spec.sampleRate,
+                    juce::jmin (0.5 * spec.sampleRate,
+                                static_cast<double> (hpFilterParameters.frequency)));
+                coeffs->coefficients =
+                    FilterVisualizerHelper<double>::cascadeSecondOrderCoefficients (
+                        coeffs->coefficients,
+                        coeffs->coefficients);
+
+                guiCoefficients[0] = coeffs;
+                break;
+            }
+
+            default:
+                guiCoefficients[0] =
+                    IIR::Coefficients<double>::makeAllPass (spec.sampleRate, 20.0f);
+                break;
+        }
+
+        // Lowshelf
+        guiCoefficients[1] = IIR::Coefficients<double>::makeLowShelf (
             spec.sampleRate,
             juce::jmin (0.5 * spec.sampleRate, static_cast<double> (lowShelfParameters.frequency)),
             lowShelfParameters.q,
             lowShelfParameters.linearGain);
 
-        std::vector<double> temp;
-        temp.resize (numSamples);
-
-        coefficients.getMagnitudeForFrequencyArray (frequencies,
-                                                    t60Data,
-                                                    numSamples,
-                                                    spec.sampleRate);
-        coefficients = *IIR::Coefficients<float>::makeHighShelf (
+        // Highshelf
+        guiCoefficients[2] = IIR::Coefficients<double>::makeHighShelf (
             spec.sampleRate,
             juce::jmin (0.5 * spec.sampleRate, static_cast<double> (highShelfParameters.frequency)),
             highShelfParameters.q,
             highShelfParameters.linearGain);
-        coefficients.getMagnitudeForFrequencyArray (frequencies,
-                                                    &temp[0],
-                                                    numSamples,
-                                                    spec.sampleRate);
+
+        repaintFV = true;
+    }
+
+    void getT60ForFrequencyArray (double* frequencies, double* t60Data, size_t numSamples)
+    {
+        std::vector<double> temp;
+        temp.resize (numSamples);
+
+        juce::dsp::IIR::Coefficients<double> coefficients;
+        updateGuiCoefficients();
+
+        for (int i = 0; i < 3; ++i)
+        {
+            coefficients = *getCoefficientsForGui (i);
+            coefficients.getMagnitudeForFrequencyArray (frequencies,
+                                                        &temp[0],
+                                                        numSamples,
+                                                        spec.sampleRate);
+        }
 
         juce::FloatVectorOperations::multiply (&temp[0], t60Data, static_cast<int> (numSamples));
         juce::FloatVectorOperations::multiply (&temp[0],
@@ -332,14 +410,27 @@ public:
     }
 
     const FdnSize getFdnSize() { return params.newNetworkSize; }
+    std::atomic<bool> repaintFV = true;
 
 private:
     //==============================================================================
-    juce::dsp::ProcessSpec spec = { -1, 0, 0 };
+    juce::dsp::ProcessSpec spec = { 48000.0, 0, 0 };
 
     juce::OwnedArray<juce::AudioBuffer<float>> delayBufferVector;
     juce::OwnedArray<juce::IIRFilter> highShelfFilters;
     juce::OwnedArray<juce::IIRFilter> lowShelfFilters;
+
+    juce::dsp::IIR::Coefficients<float>::Ptr hpCoefficients =
+        juce::dsp::IIR::Coefficients<float>::makeAllPass (48000.0, 20.0f);
+
+    juce::dsp::IIR::Coefficients<float>::Ptr additionalHpCoefficients =
+        juce::dsp::IIR::Coefficients<float>::makeAllPass (48000.0, 20.0f);
+
+    juce::OwnedArray<juce::dsp::IIR::Filter<float>> hpFilters;
+    juce::OwnedArray<juce::dsp::IIR::Filter<float>> additionalHpFilters;
+
+    juce::dsp::IIR::Coefficients<double>::Ptr guiCoefficients[3];
+
     juce::Array<int> delayPositionVector;
     juce::Array<float> feedbackGainVector;
     juce::Array<float> transferVector;
@@ -348,11 +439,13 @@ private:
     std::vector<int> indices;
 
     FilterParameter lowShelfParameters, highShelfParameters;
+    HPFilterParameter hpFilterParameters;
     float dryWet;
     float delayLength = 20;
     float overallGain;
 
     bool freeze = false;
+    bool isInitialized = false;
     FdnSize fdnSize = uninitialized;
 
     struct UpdateStruct
@@ -363,6 +456,7 @@ private:
         bool filterParametersChanged = false;
         FilterParameter newLowShelfParams;
         FilterParameter newHighShelfParams;
+        HPFilterParameter newHPFilterParams;
 
         bool delayLengthChanged = false;
         int newDelayLength = 20;
@@ -442,7 +536,7 @@ private:
             if (is_prime)
                 series.push_back (range);
 
-            range++;
+            range += 2;
         }
         return series;
     }
@@ -474,7 +568,7 @@ private:
 
     void updateFilterCoefficients()
     {
-        if (spec.sampleRate > 0)
+        if (isInitialized)
         {
             // update shelving filter parameters
             for (int channel = 0; channel < fdnSize; ++channel)
@@ -493,6 +587,47 @@ private:
                     highShelfParameters.q,
                     channelGainConversion (channel, highShelfParameters.linearGain)));
             }
+
+            juce::dsp::IIR::Coefficients<float>::Ptr tmpCoeffs;
+
+            switch (hpFilterParameters.mode)
+            {
+                case 1:
+                    tmpCoeffs = juce::dsp::IIR::Coefficients<float>::makeFirstOrderHighPass (
+                        spec.sampleRate,
+                        juce::jmin (0.5 * spec.sampleRate,
+                                    static_cast<double> (hpFilterParameters.frequency)));
+
+                    *hpCoefficients = *tmpCoeffs;
+                    break;
+                case 2:
+                    tmpCoeffs = juce::dsp::IIR::Coefficients<float>::makeHighPass (
+                        spec.sampleRate,
+                        juce::jmin (0.5 * spec.sampleRate,
+                                    static_cast<double> (hpFilterParameters.frequency)),
+                        hpFilterParameters.q);
+
+                    *hpCoefficients = *tmpCoeffs;
+                    break;
+
+                case 3:
+                    tmpCoeffs = juce::dsp::IIR::Coefficients<float>::makeHighPass (
+                        spec.sampleRate,
+                        juce::jmin (0.5 * spec.sampleRate,
+                                    static_cast<double> (hpFilterParameters.frequency)));
+                    *hpCoefficients = *tmpCoeffs;
+                    break;
+
+                default:
+                    tmpCoeffs = juce::dsp::IIR::Coefficients<float>::makeAllPass (
+                        spec.sampleRate,
+                        juce::jmin (0.5 * spec.sampleRate,
+                                    static_cast<double> (hpFilterParameters.frequency)));
+
+                    *hpCoefficients = *tmpCoeffs;
+            }
+
+            updateGuiCoefficients();
         }
     }
 
@@ -508,6 +643,8 @@ private:
                     delayBufferVector.add (new juce::AudioBuffer<float>());
                     highShelfFilters.add (new juce::IIRFilter());
                     lowShelfFilters.add (new juce::IIRFilter());
+                    hpFilters.add (new juce::dsp::IIR::Filter<float> (hpCoefficients));
+                    additionalHpFilters.add (new juce::dsp::IIR::Filter<float> (hpCoefficients));
                 }
             }
             else
@@ -516,6 +653,8 @@ private:
                 delayBufferVector.removeLast (diff);
                 highShelfFilters.removeLast (diff);
                 lowShelfFilters.removeLast (diff);
+                hpFilters.removeLast (diff);
+                additionalHpFilters.removeLast (diff);
             }
         }
         delayPositionVector.resize (newSize);
