@@ -26,46 +26,49 @@
  Use double! */
 
 template <typename type>
-class FilterVisualizerHelper {
+class FilterVisualizerHelper
+{
 public:
-    static juce::Array<type> cascadeSecondOrderCoefficients(juce::Array<type>& c0, juce::Array<type>& c1)
+    static juce::Array<type> cascadeSecondOrderCoefficients (juce::Array<type>& c0,
+                                                             juce::Array<type>& c1)
     {
         juce::Array<type> c12;
-        c12.resize(9);
+        c12.resize (9);
         const int o = 2;
 
-        c12.setUnchecked(0, c0[0] * c1[0]);
-        c12.setUnchecked(1, c0[0] * c1[1] + c0[1] * c1[0]);
-        c12.setUnchecked(2, c0[0] * c1[2] + c0[1] * c1[1] + c0[2] * c1[0]);
-        c12.setUnchecked(3, c0[1] * c1[2] + c0[2] * c1[1]);
-        c12.setUnchecked(4, c0[2] * c1[2]);
+        c12.setUnchecked (0, c0[0] * c1[0]);
+        c12.setUnchecked (1, c0[0] * c1[1] + c0[1] * c1[0]);
+        c12.setUnchecked (2, c0[0] * c1[2] + c0[1] * c1[1] + c0[2] * c1[0]);
+        c12.setUnchecked (3, c0[1] * c1[2] + c0[2] * c1[1]);
+        c12.setUnchecked (4, c0[2] * c1[2]);
 
-        c12.setUnchecked(5, c1[1+o] + c0[1+o]);
-        c12.setUnchecked(6, c1[2+o] + c0[1+o] * c1[1+o] + c0[2+o]);
-        c12.setUnchecked(7, c0[1+o] * c1[2+o] + c0[2+o] * c1[1+o]);
-        c12.setUnchecked(8, c0[2+o] * c1[2+o]);
+        c12.setUnchecked (5, c1[1 + o] + c0[1 + o]);
+        c12.setUnchecked (6, c1[2 + o] + c0[1 + o] * c1[1 + o] + c0[2 + o]);
+        c12.setUnchecked (7, c0[1 + o] * c1[2 + o] + c0[2 + o] * c1[1 + o]);
+        c12.setUnchecked (8, c0[2 + o] * c1[2 + o]);
 
         return c12;
     }
 
-    static juce::Array<type> cascadeFirstAndSecondOrderCoefficients(juce::Array<type>& firstOrder, juce::Array<type>& secondOrder)
+    static juce::Array<type> cascadeFirstAndSecondOrderCoefficients (juce::Array<type>& firstOrder,
+                                                                     juce::Array<type>& secondOrder)
     {
         juce::Array<type>& c1 = firstOrder;
         juce::Array<type>& c2 = secondOrder;
 
         juce::Array<type> c12;
-        c12.resize(7);
+        c12.resize (7);
 
         //b
-        c12.setUnchecked(0, c1[0] * c2[0]);
-        c12.setUnchecked(1, c1[0] * c2[1] + c1[1] * c2[0]);
-        c12.setUnchecked(2, c1[0] * c2[2] + c1[1] * c2[1]);
-        c12.setUnchecked(3, c1[1] * c2[2]);
+        c12.setUnchecked (0, c1[0] * c2[0]);
+        c12.setUnchecked (1, c1[0] * c2[1] + c1[1] * c2[0]);
+        c12.setUnchecked (2, c1[0] * c2[2] + c1[1] * c2[1]);
+        c12.setUnchecked (3, c1[1] * c2[2]);
 
         //a
-        c12.setUnchecked(4, c1[2] + c2[3]);
-        c12.setUnchecked(5, c1[2] * c2[3] + c2[4]);
-        c12.setUnchecked(6, c1[2] * c2[4]);
+        c12.setUnchecked (4, c1[2] + c2[3]);
+        c12.setUnchecked (5, c1[2] * c2[3] + c2[4]);
+        c12.setUnchecked (6, c1[2] * c2[4]);
 
         return c12;
     }
