@@ -1,8 +1,8 @@
 /*
  ==============================================================================
  This file is part of the IEM plug-in suite.
- Author: Daniel Rudrich
- Copyright (c) 2017 - Institute of Electronic Music and Acoustics (IEM)
+ Author: Daniel Rudrich, Felix Holzmueller
+ Copyright (c) 2022 - Institute of Electronic Music and Acoustics (IEM)
  https://iem.at
 
  The IEM plug-in suite is free software: you can redistribute it and/or modify
@@ -25,43 +25,44 @@
  */
 
 /*
-  ==============================================================================
+==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 5 End-User License
-   Agreement and JUCE 5 Privacy Policy (both updated and effective as of the
-   27th April 2017).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User
+License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-5-licence
-   Privacy Policy: www.juce.com/juce-5-privacy-policy
+   End User License Agreement: www.juce.com/juce-7-licence
+   Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
    www.gnu.org/licenses).
 
-   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES, WHETHER
-   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR PURPOSE, ARE
+   JUCE IS PROVIDED "AS IS" WITHOUT ANY WARRANTY, AND ALL WARRANTIES,
+WHETHER
+   EXPRESSED OR IMPLIED, INCLUDING MERCHANTABILITY AND FITNESS FOR
+PURPOSE, ARE
    DISCLAIMED.
 
-  ==============================================================================
+  
+==============================================================================
 */
 
 #include <JuceHeader.h>
 #include <PluginProcessor.h>
 
-extern juce::AudioProcessor* JUCE_CALLTYPE createPluginFilter();
-
 #include "MyStandaloneFilterWindow.h"
 
 namespace juce
 {
 
 //==============================================================================
-class StandaloneApp  : public JUCEApplication
+class StandaloneApp : public JUCEApplication
 {
 public:
     StandaloneApp()
@@ -70,42 +71,54 @@ public:
 
         juce::PropertiesFile::Options options;
 
-        options.applicationName     = getApplicationName();
-        options.filenameSuffix      = ".settings";
-        options.osxLibrarySubFolder = "Application Support";
-       #if JUCE_LINUX
-        options.folderName          = "~/.config";
-       #else
-        options.folderName          = "";
-       #endif
+        options.applicationName = getApplicationName();
+        options.filenameSuffix = ".settings";
+        options.osxLibrarySubFolder = "Application Support/IEMAudioPlugins";
+#if JUCE_LINUX || JUCE_BSD
+        options.folderName =
+            File::getSpecialLocation (File::userApplicationDataDirectory).getFullPathName()
+            + File::getSeparatorString() + "IEMAudioPlugins";
+#else
+        options.folderName = "IEMAudioPlugins";
+#endif
 
         appProperties.setStorageParameters (options);
     }
 
-    const juce::String getApplicationName() override              { return JucePlugin_Name; }
-    const juce::String getApplicationVersion() override           { return JucePlugin_VersionString; }
-    bool moreThanOneInstanceAllowed() override              { return true; }
-    void anotherInstanceStarted (const juce::String&) override    {}
+    const juce::String getApplicationName() override { return CharPointer_UTF8 (JucePlugin_Name); }
+    const juce::String getApplicationVersion() override { return JucePlugin_VersionString; }
+    bool moreThanOneInstanceAllowed() override { return true; }
+    void anotherInstanceStarted (const juce::String&) override {}
 
     virtual MyStandaloneFilterWindow* createWindow()
     {
-       #ifdef JucePlugin_PreferredChannelConfigurations
-        StandalonePluginHolder::PluginInOuts channels[] = { JucePlugin_PreferredChannelConfigurations };
-       #endif
+#ifdef JucePlugin_PreferredChannelConfigurations
+        StandalonePluginHolder::PluginInOuts channels[] = {
+            JucePlugin_PreferredChannelConfigurations
+        };
+#endif
 
-        return new MyStandaloneFilterWindow (getApplicationName(),
-                                           LookAndFeel::getDefaultLookAndFeel().findColour (juce::ResizableWindow::backgroundColourId),
-                                           appProperties.getUserSettings(),
-                                           false, {}, nullptr
-                                          #ifdef JucePlugin_PreferredChannelConfigurations
-                                           , juce::Array<StandalonePluginHolder::PluginInOuts> (channels, juce::numElementsInArray (channels))
-                                          #else
-                                           , {}
-                                          #endif
-                                          #if JUCE_DONT_AUTO_OPEN_MIDI_DEVICES_ON_MOBILE
-                                           , false
-                                          #endif
-                                           );
+        return new MyStandaloneFilterWindow (
+            getApplicationName(),
+            LookAndFeel::getDefaultLookAndFeel().findColour (
+                juce::ResizableWindow::backgroundColourId),
+            appProperties.getUserSettings(),
+            false,
+            {},
+            nullptr
+#ifdef JucePlugin_PreferredChannelConfigurations
+            ,
+            juce::Array<StandalonePluginHolder::PluginInOuts> (channels,
+                                                               juce::numElementsInArray (channels))
+#else
+            ,
+            {}
+#endif
+#if JUCE_DONT_AUTO_OPEN_MIDI_DEVICES_ON_MOBILE
+                ,
+            false
+#endif
+        );
     }
 
     //==============================================================================
@@ -113,9 +126,9 @@ public:
     {
         mainWindow.reset (createWindow());
 
-       #if JUCE_STANDALONE_FILTER_WINDOW_USE_KIOSK_MODE
+#if JUCE_STANDALONE_FILTER_WINDOW_USE_KIOSK_MODE
         Desktop::getInstance().setKioskModeComponent (mainWindow.get(), false);
-       #endif
+#endif
 
         mainWindow->setVisible (true);
     }
@@ -129,13 +142,17 @@ public:
     //==============================================================================
     void systemRequestedQuit() override
     {
+        if (mainWindow.get() != nullptr)
+            mainWindow->pluginHolder->savePluginState();
+
         if (ModalComponentManager::getInstance()->cancelAllModalComponents())
         {
-            juce::Timer::callAfterDelay (100, []()
-            {
-                if (auto app = JUCEApplicationBase::getInstance())
-                    app->systemRequestedQuit();
-            });
+            juce::Timer::callAfterDelay (100,
+                                         []()
+                                         {
+                                             if (auto app = JUCEApplicationBase::getInstance())
+                                                 app->systemRequestedQuit();
+                                         });
         }
         else
         {
@@ -152,6 +169,8 @@ protected:
 
 #if JucePlugin_Build_Standalone && JUCE_IOS
 
+JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wmissing-prototypes")
+
 using namespace juce;
 
 bool JUCE_CALLTYPE juce_isInterAppAudioConnected()
@@ -168,7 +187,6 @@ void JUCE_CALLTYPE juce_switchToHostApplication()
         holder->switchToHostApplication();
 }
 
-#if JUCE_MODULE_AVAILABLE_juce_gui_basics
 Image JUCE_CALLTYPE juce_getIAAHostIcon (int size)
 {
     if (auto holder = StandalonePluginHolder::getInstance())
@@ -176,7 +194,8 @@ Image JUCE_CALLTYPE juce_getIAAHostIcon (int size)
 
     return Image();
 }
-#endif
+
+JUCE_END_IGNORE_WARNINGS_GCC_LIKE
 #endif
 
 START_JUCE_APPLICATION (juce::StandaloneApp)
